#!/usr/bin/python
#
#
# Author: Antonia Rowlinson
# E-mail: b.a.rowlinson@uva.nl
#
from datetime import datetime
import tkp.utility.coordinates as coords
from scipy.stats import norm
from scipy.stats import lognorm
from scipy.optimize import leastsq
import numpy as np
import math
import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
import matplotlib.axes as axes
from astroML import density_estimation
import operator
import tkp.utility.coordinates as coords
from pyrap.quanta import quantity
from pyrap.measures import measures
import pylab
from tkp.utility.coordinates import julian_date
import os
import glob

matplotlib.rcParams.update({'font.size': 24})
matplotlib.rcParams['axes.linewidth'] = 2
matplotlib.rcParams['xtick.major.size'] = 14
matplotlib.rcParams['ytick.major.size'] = 14
matplotlib.rcParams['xtick.major.width'] = 2
matplotlib.rcParams['ytick.major.width'] = 2

def read_datafile(filename):
    info=[]
    data=open(filename,'r')
    for lines in data:
        if not lines.startswith('#'):
            lines=lines.rstrip()
            src_data=lines.split(',')
            info.append(src_data)
    data.close()
    return info


def plotfig_rates2(trans_data, a, b, xlabel, ylabel, plotname,trackAvg, thisData,timescale):
    plt.clf()
    plt.close()
    fig = plt.figure(1,figsize=(40,25))
    matplotlib.rcParams.update({'font.size': 40})
    matplotlib.rcParams.update({'axes.linewidth' : 5})
    plt.tight_layout()

    #labels=np.unique([x[4] for x in trans_data])
    labels=['This Work','Murphy et al. (2021)','Bhandari et al. (2019) A','Bhandari et al. (2019) B','Radcliffe et al. (2019)','Hancock et al. (2016)','Mooley et al. (2016)','Bell et al. (2015)','Alexander et al. (2015)','Aoki et al. (2014)','Mooley et al. (2013)','Hodge et al. (2013)','Frail et al. (2012)','Thyagarajan et al. (2011)','Bower & Saul (2011)','Bell et al. (2011)','Croft et al. (2010)','Bower et al. (2010)','de Vries et al. (2004)','Carilli et al. (2003)','Levinson et al. (2002)','Riley & Green (1998)']

    pltlabels=['This Work','Murphy et al. (2021)','Bhandari et al. (2019) A','Bhandari et al. (2019) B','Radcliffe et al. (2019)','Hancock et al. (2016)','Mooley et al. (2016)','Bell et al. (2015)','Alexander et al. (2015)','Aoki et al. (2014)','Mooley et al. (2013)','Hodge et al. (2013)','Frail et al. (2012)','Thyagarajan et al. (2011)','Bower & Saul (2011)','Bell et al. (2011)','Croft et al. (2010)','Bower et al. (2010)','de Vries et al. (2004)','Carilli et al. (2003)','Levinson et al. (2002)','Riley & Green (1998)'] #21

    
    markers=['D','*','s','D','v','8','^','s','<','*','>','p','o','*','s','D','v','8','^','s','<','*'] #22
    c=matplotlib.cm.rainbow_r(np.linspace(0,1,22))
    #c=[next(color) for a in range(10)]
    #plt.plot(x,y,c=c)
    
    pylab.subplots_adjust(wspace=0.001)
    
    ax1 = fig.add_subplot(121)
    ax2 = fig.add_subplot(122, sharey=ax1)

    box = ax1.get_position()
    ax1.set_position([box.x0, box.y0 + box.height * 0.15,box.width, box.height * 0.9])
    box = ax2.get_position()
    ax2.set_position([box.x0, box.y0 + box.height * 0.15,box.width, box.height * 0.9])
    
    for a in range(len(labels)):
        if labels[a]!= 'This Work':
            if labels[a] in pltlabels:
                ax2.plot([trans_data[x][0] for x in range(len(trans_data)) if trans_data[x][4]==labels[a]],[trans_data[x][1] for x in range(len(trans_data)) if trans_data[x][4]==labels[a]],mew=3, marker=markers[a],markersize=30,c=c[a],label=labels[a],ls='none')
                ax2.quiver([trans_data[x][0] for x in range(len(trans_data)) if trans_data[x][4]==labels[a] if trans_data[x][3]=='0'],[trans_data[x][1] for x in range(len(trans_data)) if trans_data[x][4]==labels[a] if trans_data[x][3]=='0'],0,-30)
            
                ax1.plot([trans_data[x][2] for x in range(len(trans_data)) if trans_data[x][4]==labels[a]],[trans_data[x][1] for x in range(len(trans_data)) if trans_data[x][4]==labels[a]],mew=3,marker=markers[a],markersize=30,c=c[a],label=labels[a],ls='-', linewidth=4)
                ax1.quiver([trans_data[x][2] for x in range(len(trans_data)) if trans_data[x][4]==labels[a] if trans_data[x][3]=='0'],[trans_data[x][1] for x in range(len(trans_data)) if trans_data[x][4]==labels[a] if trans_data[x][3]=='0'],0,-30)
        else:
            ax2.plot(thisData['flxDensity'],thisData['surfDensity'],'-',c=c[a],lw='8')
            ax2.plot(max(thisData['flxDensity']),min(thisData['surfDensity']),markers[a], c=c[0],markersize=30,label=labels[a])
            ax2.quiver(max(thisData['flxDensity']),min(thisData['surfDensity']),0,-30)
            ax1.plot(timescale,min(thisData['surfDensity']),markers[a], c=c[a],markersize=30,label=labels[a])
            ax1.quiver(timescale,min(thisData['surfDensity']),0,-30)

    
    ax1.set_xscale('log')
    ax2.set_xscale('log')
    ax1.set_yscale('log')
    ax2.set_yscale('log')
    ax2.set_xlim([1e-5,10])
    ax1.set_xlim([1e-5,3e4])
    ax1.set_ylim([1e-6,100])
    ax2.set_xlabel('Sensitivity (Jy)')
    ax1.set_xlabel('Timescale (days)')
    ax1.set_ylabel(r'Surface density (deg$^{-2}$)')
    yticklabels = ax2.get_yticklabels()
    pylab.setp(yticklabels,visible=False)
    ax1.axvline(x=1.157e-5, linewidth=4, color='k', linestyle='--')
    ax1.text(1.157e-5*1.2,5e-4,'1 second',rotation=90)
    ax1.axvline(x=6.944e-4, linewidth=4, color='k', linestyle='--')
    ax1.text(6.944e-4*1.2,5e-4,'1 minute',rotation=90)
    ax1.axvline(x=0.041667, linewidth=4, color='k', linestyle='--')
    ax1.text(0.041667*1.2,5e-4,'1 hour',rotation=90)
    ax1.axvline(x=1, linewidth=4, color='k', linestyle='--')
    ax1.text(1*1.2,5e-4,'1 day',rotation=90)
    ax1.axvline(x=30, linewidth=4, color='k', linestyle='--')
    ax1.text(30*1.2,5e-4,'1 month',rotation=90)
    ax1.axvline(x=365, linewidth=4, color='k', linestyle='--')
    ax1.text(365*1.2,5e-4,'1 year',rotation=90)
    ax1.axvline(x=3650, linewidth=4, color='k', linestyle='--')
    ax1.text(365*10*1.2,5e-4,'10 years',rotation=90)
    ax1.tick_params(axis='x', pad=20)
    ax2.tick_params(axis='x', pad=20)
    ax1.tick_params(axis='y', pad=20)
    ax2.tick_params(axis='y', pad=20)
    ax1.legend(bbox_to_anchor=(-0.15, -0.32), loc='lower left', borderaxespad=0.,numpoints=1, fontsize = 'small', ncol=5)
    plt.savefig(plotname+'.png')
    plt.close(fig)
    matplotlib.rcParams.update({'font.size': 26})
    matplotlib.rcParams.update({'axes.linewidth' : 2})

